<?php

//Add editor styling;
add_editor_style('editor-style.css');

// Load up our theme options page and related code. 
require( get_template_directory() . '/theme-options.php' );


//Add custom background; it's SO easy.
add_theme_support( 'custom-background' );

// Add default posts and comments RSS feed links to <head>.
add_theme_support( 'automatic-feed-links' );

// Make theme available for translation
// Translations can be filed in the /languages/ directory
load_theme_textdomain( 'dragonfly', get_template_directory() . '/languages' );

$locale = get_locale();
$locale_file = get_template_directory() . "/languages/$locale.php";
if ( is_readable($locale_file) )
  require_once($locale_file);


// Get the page number
function get_page_number() {
  if (get_query_var('paged')) {
    print ' | ' . __( 'Page ' , 'dragonfly') . get_query_var('paged');
  }
} // end get_page_number

// Register widgetized areas
function dragonfly_widgets_init() {
  // Area 1
  register_sidebar( array (
			   'name' => __('Top Left Widget Area', 'dragonfly'),
			   'id' => 'top-left-widget-area',
			   'description' => __( 'A widget area between the navigation and content, on the top-right side.', 'dragonfly' ),
			   'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			   'after_widget' => "</li>",
			   'before_title' => '<h3 class="widget-title">',
			   'after_title' => '</h3>',
			   ) );

  // Area 2
  register_sidebar( array (
			   'name' => __('Top Right Widget Area', 'dragonfly'),
			   'id' => 'top-right-widget-area',
			   'description' => __( 'A widget area between the navigation and content, on the top-right side.', 'dragonfly' ),
			   'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			   'after_widget' => "</li>",
			   'before_title' => '<h3 class="widget-title">',
			   'after_title' => '</h3>',
			   ) );

  // Area 3
  register_sidebar( array (
			   'name' => __('Sidebar', 'dragonfly'),
			   'id' => 'secondary-widget-area',
			   'description' => __( 'A sidebar widget area.', 'dragonfly' ),
			   'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			   'after_widget' => "</li>",
			   'before_title' => '<h3 class="widget-title">',
			   'after_title' => '</h3>',
			   ) );

  // Area 4
  register_sidebar( array (
			   'name' => __('Footer Widget Area', 'dragonfly'),
			   'id' => 'footer-widget-area',
			   'description' => __( 'A widget-area in the bottom-left of the footer.', 'dragonfly' ),
			   'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			   'after_widget' => "</li>",
			   'before_title' => '<h3 class="widget-title">',
			   'after_title' => '</h3>',
			   ) );

}

add_action( 'widgets_init', 'dragonfly_widgets_init' );


// Pre-set Widgets
$preset_widgets = array (
			 'top-left-aside'  => array( 'pages', 'categories'),
			 'top-right-aside' => array( 'archives'),
			 'secondary-aside'  => array( 'links', 'meta' ),
			 'footer-aside' => array('search'),
			 );
if ( isset( $_GET['activated'] ) ) {
  update_option( 'sidebars_widgets', $preset_widgets );
}

// Produces an avatar image with the hCard-compliant photo class
function commenter_link() {
  $commenter = get_comment_author_link();
  if ( ereg( '<a[^>]* class=[^>]+>', $commenter ) ) {
    $commenter = ereg_replace( '(<a[^>]* class=[\'"]?)', '\\1url ' , $commenter );
  } else {
    $commenter = ereg_replace( '(<a )/', '\\1class="url "' , $commenter );
  }
  $avatar_email = get_comment_author_email();
  $avatar = str_replace( "class='avatar", "class='photo avatar", get_avatar( $avatar_email, 80 ) );
  echo $avatar . ' <span class="fn n">' . $commenter . '</span>';
} // end commenter_link

// Register Custom Menu

register_nav_menus( array(
			  'primary' => __( 'Primary Menu', 'dragonfly' ),
			  ) );

//Required for theme submission:
//Specify a theme 

if ( ! isset( $content_width ) ) 
  $content_width = 465;

?>


