<?php 
//Thanks to the tutorial at http://ottopress.com/2009/wordpress-settings-api-tutorial/ and to the Twenty Eleven theme for inspiring this code!

//defining settings to start it all up
add_action( 'admin_init', 'dragonfly_admin_init' );
function dragonfly_admin_init() {
  register_setting(
		   'dragonfly_options',	      // Options group, see settings_fields() call in dragonfly_options_page()
		   'dragonfly_theme_options', // Database option, see dragonfly_get_theme_options()
		   'dragonfly_theme_options_validate' // The sanitization callback, see dragonfly_theme_options_validate()
		   );

  // Register our settings field group
  add_settings_section(
		       'dragonfly_color_schemes', // Unique identifier for the settings section
		       '', // Section title (we don't want one)
		       '__return_false', // Section callback (we don't want anything)
		       'theme_options' // Menu slug, used to uniquely identify the page; see dragonfly_add_theme_page()
		       );

  // Register our individual settings fields
  add_settings_field(
		     'color_scheme',  // Unique identifier for the field for this section
		     '', // Setting field label
		     'dragonfly_settings_field_color_scheme', // Function that renders the settings field
		     'theme_options', // Menu slug, used to uniquely identify the page; see dragonfly_add_theme_page()
		     'dragonfly_color_schemes' // Settings section. Same as the first argument in the add_settings_section() above
		     );
}


//add the theme options page
function dragonfly_add_theme_page() {
  add_theme_page(
		 __( 'Dragonfly Theme Options', 'dragonfly' ),	 // Name of page
		 __( 'Dragonfly Theme Options', 'dragonfly' ),	 // Label in menu
		 'edit_theme_options',			  // Capability required
		 'theme_options',			  // Menu slug, used to uniquely identify the page
		 'dragonfly_options_page' // Function that renders the options page
		 );
}

add_action( 'admin_menu', 'dragonfly_add_theme_page' );



//array of the color scheme option data
function dragonfly_color_schemes() {
  $color_scheme_options = array(
				'greens' => array(
						  'value' => 'greens',
						  'label' => __( 'Greens', 'dragonfly' ),
						  'thumbnail' => get_template_directory_uri() . '/images/greens-prev.png'
						  ),
				'blues' => array(
						 'value' => 'blues',
						 'label' => __( 'Blues', 'dragonfly' ),
						 'thumbnail' => get_template_directory_uri() . '/images/blues-prev.png'
						 ),
				'purples' => array(
						   'value' => 'purples',
						   'label' => __( 'Purples', 'dragonfly' ),
						   'thumbnail' => get_template_directory_uri() . '/images/purples-prev.png'
						   ),
				);

  return apply_filters( 'dragonfly_color_schemes', $color_scheme_options );
}


//This is the options function/array.
function dragonfly_get_default_theme_options() {
  $default_theme_options = array(
				 'color_scheme' => 'greens',
				 );
  return apply_filters( 'dragonfly_default_theme_options', $default_theme_options );
}


function dragonfly_get_theme_options() {
  return get_option( 'dragonfly_theme_options', dragonfly_get_default_theme_options() );
}


//function to generate the form for the color scheme on the options page.
function dragonfly_settings_field_color_scheme() {
  $options = dragonfly_get_theme_options();
  ?><ul><?php
  foreach ( dragonfly_color_schemes() as $scheme ) {
    ?>
    <li><label class="description">
		
      <img src="<?php echo esc_url( $scheme['thumbnail'] ); ?>" width="136" height="122" alt="" />
      <?php echo $scheme['label']; ?>
		
      <input type="radio" name="dragonfly_theme_options[color_scheme]" value="<?php echo esc_attr( $scheme['value'] ); ?>" <?php checked( $options['color_scheme'], $scheme['value'] ); ?> />
      </label></li>
	  <?php
	  }
  ?></ul><?php
}

//function to generate the page around the color scheme form, including the form tags.
function dragonfly_options_page() {
  ?>
  <div class="wrap">
    <h2>Twenty Eleven Options</h2>
    <p>Choose a color scheme:</p>
    <form action="options.php" method="post">
    <?php
    settings_fields( 'dragonfly_options' );
  do_settings_sections( 'theme_options' );
  submit_button();
  ?>
  </form>
      </div>
      <?php
      }


//This is where we build the sanitization/validation function.
function dragonfly_theme_options_validate( $input ) {
  $output = $defaults = dragonfly_get_default_theme_options();

  // Color scheme must be in our array of color scheme options
  if ( isset( $input['color_scheme'] ) && array_key_exists( $input['color_scheme'], dragonfly_color_schemes() ) )
    $output['color_scheme'] = $input['color_scheme'];

  return apply_filters( 'dragonfly_theme_options_validate', $output, $input, $defaults );
}


//FINALLY we enqueue the style for the current color scheme:
function dragonfly_enqueue_color_scheme() {
  $options = dragonfly_get_theme_options();
  $color_scheme = $options['color_scheme'];

  if ( 'blues' == $color_scheme )
    wp_enqueue_style( 'blues', get_template_directory_uri() . '/blues.css', array(), null );
  if ( 'purples' == $color_scheme )
    wp_enqueue_style( 'purples', get_template_directory_uri() . '/purples.css', array(), null );

  do_action( 'dragonfly_enqueue_color_scheme', $color_scheme );
}
add_action( 'wp_enqueue_scripts', 'dragonfly_enqueue_color_scheme' );

